@@ -1,24 +1,27 @@
 #!/bin/bash
 # upload.sh
 
-# Upload file pair (Filename.lsm, Filename.tar.gz)
-# to incoming directory at Sunsite (metalab.unc.edu).
+#  Upload file pair (Filename.lsm, Filename.tar.gz)
+#+ to incoming directory at Sunsite/UNC (ibiblio.org).
+#  Filename.tar.gz is the tarball itself.
+#  Filename.lsm is the descriptor file.
+
 
 E_ARGERROR=65
 
 if [ -z "$1" ]
 then
-  echo "Usage: `basename $0` filename"
+  echo "Usage: `basename $0` Filename-to-upload"
   exit $E_ARGERROR
 fi  
 
 
 Filename=`basename $1`           # Strips pathname out of file name.
 
-Server="metalab.unc.edu"
+Server="ibiblio.org"
 Directory="/incoming/Linux"
-# These need not be hard-coded into script,
-# but may instead be changed to command line argument.
+#  These need not be hard-coded into script,
+#+ but may instead be changed to command line argument.
 
 Password="your.e-mail.address"   # Change above to suit.
 
