@@ -7,9 +7,8 @@ PIPS=6          # A die has 6 pips.
 MAXTHROWS=600   # Increase this, if you have nothing better to do with your time.
 throw=0         # Throw count.
 
-zeroes=0        # Must initialize counts to zero.
-ones=0          # since an uninitialized variable is null, not zero.
-twos=0
+ones=0          #  Must initialize counts to zero,
+twos=0          #+ since an uninitialized variable is null, not zero.
 threes=0
 fours=0
 fives=0
@@ -51,15 +50,19 @@ done
 
 print_result
 
-# The scores should distribute fairly evenly, assuming RANDOM is fairly random.
-# With $MAXTHROWS at 600, all should cluster around 100, plus-or-minus 20 or so.
+#  The scores should distribute fairly evenly, assuming RANDOM is fairly random.
+#  With $MAXTHROWS at 600, all should cluster around 100, plus-or-minus 20 or so.
 #
-# Keep in mind that RANDOM is a pseudorandom generator,
-# and not a spectacularly good one at that.
+#  Keep in mind that RANDOM is a pseudorandom generator,
+#+ and not a spectacularly good one at that.
+
+#  Randomness is a deep and complex subject.
+#  Sufficiently long "random" sequences may exhibit
+#+ chaotic and other "non-random" behavior.
 
 # Exercise (easy):
 # ---------------
 # Rewrite this script to flip a coin 1000 times.
-# Choices are "HEADS" or "TAILS".
+# Choices are "HEADS" and "TAILS".
 
 exit 0
